@@ -4,7 +4,7 @@
 
 __author__ = """Bruno Paulin"""
 __email__ = "brunopaulin@bpaulin.net"
-__version__ = "1.0.3"
+__version__ = "2.0.1"
 
 # flake8: noqa
-from .bpbgate import BpbGate, SESSION_EVENT
+from .bpbgate import BpbCommandSession, BpbEventSession
